@@ -1,7 +1,7 @@
 __doc__ = '''Compare IT Utility'''
 
-__all__ = [ "CompareText", "CompareExcelData", "get_string_diffs"]
+__all__ = [ "CompareText", "CompareExcelData" ]
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
 from .diff import CompareText, CompareExcelData, get_string_diffs
\ No newline at end of file
